import com.rinearn.graph2d.RinearnGraph2D;
import com.rinearn.graph2d.RinearnGraph2DOptionItem;
import com.rinearn.graph2d.RinearnGraph2DOptionParameter;


/**
 * 配列に格納されたデータをプロットし、
 * プロット範囲やオプションの設定などを行うサンプルコードです。
 */
public class Sample3 {

	public static void main(String[] args) {
		
		// 座標値データの用意
		int n = 101;
		double[] x = new double[n];
		double[] y = new double[n];
		for(int i=0; i<n; i++) {
			x[i] = i*0.1;
			y[i] = Math.sin(x[i]);
		}
		
		// 座標値データをグラフに渡してプロット
		RinearnGraph2D graph = new RinearnGraph2D();
		graph.setData(x, y);
		
		// プロット範囲を設定
		graph.setXRange(0.0, 8.0);
		graph.setYRange(-1.25, 1.25);
		
		// グラフスクリーンのサイズを設定
		graph.setScreenSize(680, 380);
		
		// タイトルとラベルを設定
		graph.setTitle("sin 関数のグラフ");
		graph.setXLabel("x");
		graph.setYLabel("sin (x)");
		
		// プロットオプションを選択（点プロット無効化と線プロット有効化）
		graph.setOptionSelected(RinearnGraph2DOptionItem.POINT, false);
		graph.setOptionSelected(RinearnGraph2DOptionItem.LINE, true);
		
		// プロットオプションのパラメータを設定（線プロットの線幅を指定）
		RinearnGraph2DOptionParameter parameter 
				= new RinearnGraph2DOptionParameter();
		parameter.setLineWidth(3.0);
		graph.setOptionParameter(parameter);
		
		// 設定ファイルから設定を読み込みたい場合は、以下を有効にしてください。
		/*
		try {
			graph.loadConfigurationFile(new java.io.File("RinearnGraph2DSetting.ini"));
		} catch (java.io.FileNotFoundException fnfe) {
			System.err.println("設定ファイルが見つかりませんでした。");
		} catch (java.io.IOException ioe) {
			System.err.println("設定ファイルを開くのに失敗しました。");
		}
		*/
		
		// グラフを画像ファイルに出力したい場合は、以下を有効にしてください。
		/*
		try {
			graph.exportImageFile(new java.io.File("graph.png"), 1.0);
		} catch (java.io.IOException ioe) {
			System.err.println("ファイル出力に失敗しました。");
		}
		*/
	}
}
