import com.rinearn.graph2d.RinearnGraph2D;
import com.rinearn.graph2d.RinearnGraph2DOptionItem;
import com.rinearn.graph2d.renderer.RinearnGraph2DRenderer;
import com.rinearn.graph2d.event.RinearnGraph2DPlottingEvent;
import com.rinearn.graph2d.event.RinearnGraph2DPlottingListener;
import java.awt.Color;


/**
 * グラフの描画エンジンを直接操作して、
 * 自由な位置に点や線を描くサンプルコードです。
 * 
 * Sample5 との違いは、グラフの再描画が必要になったらイベントとして受け取り、
 * 描画処理を再実行するようにしている点です。
 * これにより、マウス操作やメニュー操作でグラフ範囲の変更などを行っても、内容が消えずに表示されます。
 */
public class Sample6 implements RinearnGraph2DPlottingListener {
	RinearnGraph2D graph;
	RinearnGraph2DRenderer renderer;

	public static void main(String[] args) {
		new Sample6();
	}
	
	// グラフの起動と初期設定
	public Sample6() {

		// グラフを起動してレンダラー（描画エンジン）を取得
		this.graph = new RinearnGraph2D();
		this.renderer = graph.getRenderer();

		// 再描画が必要になったらイベントで受け取れるようにリスナー登録
		this.graph.addPlottingListener(this);
		
		// 描画処理を実行してスクリーンを3DCGレンダリング
		this.draw();
		renderer.render();
	}

    // 描画エンジンによる描画処理
	public void draw() {
        
		// グラフ領域内の(0.3, 0.5)の位置に、半径8ピクセルで赤色の点を描画
		renderer.drawPoint(0.3, 0.5, 8.0, Color.RED);

		// グラフ領域内の(-0.2,-0.3)と(0.8,0.5)を結ぶ、
		// 太さ3ピクセルで青色の線を描画
		renderer.drawLine(-0.2, -0.3, 0.8, 0.5, 3.0, Color.BLUE);
	}

	// 再描画が必要になった際に呼ばれるイベント処理
	@Override
	public void plottingRequested(RinearnGraph2DPlottingEvent e) {
		// 描画処理を再実行
		this.draw();
	}

	// 以下のイベント処理はここでは何もしない
	@Override
	public void plottingCanceled(RinearnGraph2DPlottingEvent e) {
	}
	@Override
	public void plottingFinished(RinearnGraph2DPlottingEvent e) {
	}
}
